.. _updates:

Updates
=======
If you'd like to stay up to date on the community and development of Eve,
there are several options:

Blog
----
`Eve News <http://blog.python-eve.org>`_ is the official blog of the Eve project.

Twitter
-------
I often tweet about new features and releases of Eve. Follow `@nicolaiarocci
<https://twitter.com/nicolaiarocci>`_.

Mailing List
------------
The `mailing list`_ is intended to be a low traffic resource for both
developers/contributors and API maintainers looking for help or requesting
feedback.

GitHub
------
Of course the best way to track the development of Eve is through
`the GitHub repo <https://github.com/pyeve/eve>`_.

.. _`mailing list`: https://groups.google.com/forum/#!forum/python-eve
